Index: src/gpu/GrProgramDesc.h |
diff --git a/src/gpu/GrProgramDesc.h b/src/gpu/GrProgramDesc.h |
index 13dd14935d8dff2992dcfebbeb94ab6a7f1bd0f4..9585e058b4a2029b5471e61c61f7ba38205cc9bc 100644 |
--- a/src/gpu/GrProgramDesc.h |
+++ b/src/gpu/GrProgramDesc.h |
@@ -70,15 +70,16 @@ public: |
} |
struct KeyHeader { |
- uint8_t fFragPosKey; // set by GrGLShaderBuilder if there are |
- // effects that read the fragment position. |
- // Otherwise, 0. |
+ // Set by GrGLShaderBuilder if there are effects that read the fragment position. |
+ // Otherwise, 0. |
+ uint8_t fFragPosKey; |
+ // Set to uniquely idenitify any swizzling of the shader's output color(s). |
+ uint8_t fOutputSwizzle; |
uint8_t fSnapVerticesToPixelCenters; |
int8_t fColorEffectCnt; |
int8_t fCoverageEffectCnt; |
uint8_t fIgnoresCoverage; |
}; |
- GR_STATIC_ASSERT(sizeof(KeyHeader) == 5); |
int numColorEffects() const { |
return this->header().fColorEffectCnt; |